(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[75913],{75913:function(e,t,r){"use strict";r.r(t),r(73214),r(96900),r(26364),r(86632),r(10853),r(61928),r(45007),r(54883),r(68995),r(18821),r(54994),r(4845);var n=r(89526),i=r(25002);function a(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}t.default=function(e){var t=e.url,r=e.content_parameters,o=e.automatic_resizing,l=n.useRef(null),c=n.useRef(null);return(0,n.useEffect)((function(){var e;if(null===(e=l.current)||void 0===e||e.submit(),o){var t=document.querySelector(".richie-react--lti-consumer");(0,i.iframeResizer)({minHeight:null==t?void 0:t.clientHeight},c.current),null==t||t.classList.remove("aspect-ratio"),null==t||t.attributes.removeNamedItem("style")}}),[]),n.createElement("div",{className:"lti-consumer"},n.createElement("form",{id:"lti_form",ref:l,action:t,method:"POST",encType:"application/x-www-form-urlencoded",target:"lti_iframe",style:{display:"none"}},Object.entries(r).map((function(e){var t,r,i=(r=2,function(e){if(Array.isArray(e))return e}(t=e)||function(e,t){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e)){var r=[],n=!0,i=!1,a=void 0;try{for(var o,l=e[Symbol.iterator]();!(n=(o=l.next()).done)&&(r.push(o.value),!t||r.length!==t);n=!0);}catch(e){i=!0,a=e}finally{try{n||null==l.return||l.return()}finally{if(i)throw a}}return r}}(t,r)||function(e,t){if(e){if("string"==typeof e)return a(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?a(e,t):void 0}}(t,r)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()),o=i[0],l=i[1];return n.createElement("input",{key:o,type:"hidden",name:o,value:l})}))),n.createElement("iframe",{ref:c,name:"lti_iframe",title:t,src:t,allow:"microphone *; camera *; midi *; geolocation *; encrypted-media *; fullscreen *",allowFullScreen:!0}))}}}]);
//# sourceMappingURL=75913.0827f08d842d2dc14db8.index.js.map